# MkDocs Moonstone Theme

This project provides a theme optimized for developer and API documentation to be used with [MkDocs](https://www.mkdocs.org/) projects.

## Installation

Install the theme with pip:

    pip install mkdocs-moonstone

After the theme is installed, edit your [mkdocs.yml] file and set the theme
[name] to `moonstone`:

    theme:
        name: moonstone

## Documentation

To learn more about Moonstone and its configuration options [visit the project's documentation](https://byrnereese.github.io/mkdocs-moonstone/).
